<?php

class WP_Embed_FB_Admin {
	/**
	 * @param string $hook_suffix
	 */
	static function admin_enqueue_scripts( $hook_suffix ) {
		if ( $hook_suffix == 'settings_page_embedfacebook' ) {
			global $wp_scripts;
			wp_enqueue_script( 'wpemfb-admin', WP_Embed_FB_Plugin::get_url() . 'lib/js/admin.js', array( 'jquery-ui-accordion' ) );
			$queryui = $wp_scripts->query( 'jquery-ui-core' );
			$url     = "https://ajax.googleapis.com/ajax/libs/jqueryui/" . $queryui->ver . "/themes/smoothness/jquery-ui.css";
			wp_enqueue_style( 'jquery-ui-start', $url, false, null );
		}
	}

	static function admin_init(  ) {
		$theme = get_option( 'wpemfb_theme' );
		add_editor_style( WP_Embed_FB_Plugin::get_url() . '/templates/' . $theme . '/' . $theme . '.css' );
	}

	static function add_page() {
		add_options_page( 'EmbedFacebook', 'Embed Facebook', 'manage_options', 'embedfacebook', array(
			__CLASS__,
			'embedfb_page'
		) );
	}

	/**
	 * @param $option string option name
	 * @param $type string  direct or true/false
	 */
	static function save_option( $option, $type ) {
		if ( $type == 'direct' ) {
			if ( isset( $_POST[ $option ] ) ) {
				update_option( $option, sanitize_text_field($_POST[ $option ]) );
			}
		}
		elseif($type == 'bool') {
			if ( isset( $_POST[ $option ] ) ) {
				update_option( $option, 'true' );
			} else {
				update_option( $option, 'false' );
			}
		}
		elseif($type == 'inverse') {
			if ( !isset( $_POST[ $option ] ) ) {
				update_option( $option, 'true' );
			} else {
				update_option( $option, 'false' );
			}
		}
	}

	static function savedata() {
		if ( isset( $_POST['wpemfb_app_secret'], $_POST['wpemfb_app_id'] ) ) {

			$options = WP_Embed_FB_Plugin::getdefaults();

			foreach ( $options as $option => $value ) {
				if( $value == 'true' || $value == 'false' ){
					$type = (strpos($option,'_raw_') !== false) ? 'inverse':'bool';
				} else {
					$type = 'direct';
				}
				self::save_option( $option, $type );
			}
			if ( isset( $_POST['wpemfb_max_width'] ) && is_int( $_POST['wpemfb_max_width'] ) ) {
				$prop = get_option( 'wpemfb_proportions' ) * $_POST['wpemfb_max_width'];
				update_option( 'wpemfb_height', $prop );
			}
		}
		/**
		 * Save extra options, requires coordination with 'wpemfb_options' action
		 *
		 * @since 1.8
		 *
		 */
		do_action( 'wpemfb_admin_save_data' );
	}

	static function field( $type, $name, $label, $args = array() ) {
		switch ( $type ) {
			case 'checkbox':
				if(strpos($name,'_raw_') !== false) :
					$checked = ( get_option( $name ) === 'true' ) ? '' : 'checked';
				else :
					$checked = ( get_option( $name ) === 'true' ) ? 'checked' : '';
				endif;

				ob_start();
				?>
				<tr valign="middle">
					<th><?php echo $label ?></th>
					<td>
						<input type="checkbox"
						       name="<?php echo $name ?>" <?php echo $checked ?> />
					</td>
				</tr>
				<?php
				ob_end_flush();
				break;
			default:
				ob_start();
				?>
				<tr valign="middle">
					<th><?php echo $label ?></th>
					<td>
						<input id="<?php echo $name ?>"
							   type="<?php echo $type ?>"
						       name="<?php echo $name ?>" <?php echo isset( $args['required'] ) ? 'required' : '' ?>
						       value="<?php echo get_option( $name ) ?>" size="38"/>
					</td>
				</tr>
				<?php
				ob_end_flush();
				break;
		}
	}

	static function section( $title = '' ) {
		if ( ! empty( $title ) ) :
			?>
			<h5><?php echo $title ?></h5>
			<div>
			<table>
			<tbody>
			<?php
		else :
			?>
			</tbody>
			</table>
			</div>
			<?php
		endif;
	}

	static function embedfb_page() {
		if ( isset( $_POST['save-data'] ) && wp_verify_nonce( $_POST['save-data'], 'wp-embed-facebook' ) ) {
			self::savedata();

		}
		$sel1 = ( get_option( 'wpemfb_theme' ) === 'default' ) ? 'selected' : '';
		$sel2 = ( get_option( 'wpemfb_theme' ) === 'classic' ) ? 'selected' : '';

		?>
		<style>
			.ui-widget-content th {
				font-weight: normal;
				padding-right: 10px;
			}

			.settings-col {
				width: 50% !important;
				padding-right: 2% !important;
				text-align: left !important;
			}

			.welcome-panel-last {
				width: 47% !important;
				text-align: center;
			}

			@media (max-width: 870px) {
				.settings-col {
					width: 100% !important;
				}

				.welcome-panel-last {
					width: 100% !important;
				}
			}
			.welcome-panel-last .button-red {
				background: #D2002C none repeat scroll 0% 0%;
				border-color: #AA0012;
				box-shadow: 0px 1px 0px rgba(230, 14, 23, 0.5) inset, 0px 1px 0px rgba(173, 173, 173, 0.15);
				color: #FFF;
				text-decoration: none;
			}
			.welcome-panel-last .button-red:focus, .welcome-panel-last .button-red:hover {
				background: #AB1F42 none repeat scroll 0% 0%;
				border-color: #AA0012;
				box-shadow: 0px 1px 0px rgba(230, 14, 23, 0.5) inset;
				color: #FFF;
			}
			.welcome-panel-last p {
				font-size: 14px;
				line-height: 14px;
				margin: 0;
				padding: 0 0 16px;
			}
			.welcome-panel-last h4 {
				padding: 0 0 10px;
			}
		</style>
		<div class="wrap">
			<h2>WP Embed Facebook</h2>

			<div class="welcome-panel">
				<div class="welcome-panel-content">
					<div class="welcome-panel-column-container">
						<div class="welcome-panel-column settings-col">
							<form id="config-form" action="#" method="post">
								<?php wp_nonce_field( 'wp-embed-facebook', 'save-data' ); ?>
								<div id="accordion">
									<?php
									self::section( __( 'Facebook application data', 'wp-embed-facebook' ) );
									self::field( 'text', 'wpemfb_app_id', __( 'App ID', 'wp-embed-facebook' ), array( 'required' => 'true' ) );
									self::field( 'text', 'wpemfb_app_secret', __( 'App Secret', 'wp-embed-facebook' ), array( 'required' => 'true' ) );
									self::section();
									?>
									<?php self::section( __( "General ", 'wp-embed-facebook' ) ); ?>
									<tr valign="middle">
										<th><?php _e( "Template to use", 'wp-embed-facebook' ) ?></th>
										<td>
											<select name="wpemfb_theme">
												<option value="default" <?php echo $sel1 ?> >Default</option>
												<option value="classic" <?php echo $sel2 ?> >Classic</option>
												<?php
												/**
												 * Add a new theme option
												 * @since 1.8
												 */
												do_action( 'wpemfb_admin_theme' );
												?>
											</select>
										</td>
									</tr>
									<?php
									self::field( 'number', 'wpemfb_max_width', __( 'Embed Max-Width', 'wp-embed-facebook' ) );
									self::section();

									self::section(__( "Album ", 'wp-embed-facebook' ));
									self::field( 'number', 'wpemfb_max_photos', __( 'Number of Photos <br>on Embedded Albums', 'wp-embed-facebook' ) );
									self::section();

									self::section(__( "Event ", 'wp-embed-facebook' ));
									self::field( 'checkbox', 'wpemfb_ev_local_tz', __( 'Show events on local time', 'wp-embed-facebook' ) );
									self::section();

									self::section( __( "Pages ", 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_raw_page', __( 'Embed Pages as Social Plugins', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_show_like', __( 'Show like button', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_show_posts', __( 'Show latest posts', 'wp-embed-facebook' ) );
									self::field( 'number', 'wpemfb_max_posts', __( 'Number of posts', 'wp-embed-facebook' ) );
									self::section();

									self::section(__( "Photo ", 'wp-embed-facebook' ));
									self::field( 'checkbox', 'wpemfb_raw_photo', __( 'Embed Photos as Social Plugins', 'wp-embed-facebook' ) );
									self::section();

									self::section(__( "Post ", 'wp-embed-facebook' ));
									self::field( 'checkbox', 'wpemfb_raw_post', __( 'Embed Posts as Social Plugins', 'wp-embed-facebook' ) );
									self::section();

									self::section(__( "Profile ", 'wp-embed-facebook' ));
									self::field( 'checkbox', 'wpemfb_show_follow', __( 'Show follow button <br>on Embedded Profiles', 'wp-embed-facebook' ) );
									self::section();

									self::section(__( "Video ", 'wp-embed-facebook' ));
									self::field( 'checkbox', 'wpemfb_raw_video', __( 'Embed Videos as Social Plugins', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_video_as_post', __( 'Use Posts social plugin', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_video_ratio', __( 'Force 16:9 ratio', 'wp-embed-facebook' ) );
									//self::field( 'checkbox', 'wpemfb_raw_video_fb', __( 'Use Facebook embed code on raw videos', 'wp-embed-facebook' ) );
									//TODO update class and delete 'wpemfb_raw_video_fb' option forever
									self::section();
									/**
									 * Add more options to the plugin page save them with 'wpemfb_admin_save_data' action
									 * @since 1.8
									 */
									do_action( 'wpemfb_options' );
									self::section( __( 'Advanced ', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_enqueue_style', __( 'Enqueue Styles', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_fb_root', __( 'Add fb-root on top of content', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_enq_lightbox', __( 'Enqueue Lightbox script', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_enq_wpemfb', __( 'Enqueue WPEmbedFB script', 'wp-embed-facebook' ) );
									self::field( 'checkbox', 'wpemfb_enq_fbjs', __( 'Enqueue Facebook SDK', 'wp-embed-facebook' ) );
									self::section();
									?>
								</div>
								<p><?php _e('All options can be overwritten using the [facebook=url ]','wp-embed-facebook') ?> <a href="http://www.wpembedfb.com/documentation/shortcodes/">shortcode</a></p>
								<input type="submit" name="submit" class="button button-primary alignright"
								       value="<?php _e( 'Save', 'wp-embed-facebook' ) ?>"/>
								<br>
								<br>
							</form>
						</div>
						<div class="welcome-panel-column welcome-panel-last">
							<?php ob_start(); ?>
							<h4><?php _e( "Keep this plugin's core free and accessible to all.", 'wp-embed-facebook' ) ?></h4>
							<p><strong><a href="http://wordpress.org/plugins/wp-embed-facebook">Rate it <span style="color: gold;">&#9733;&#9733;&#9733;&#9733;&#9733;</span></strong></a></p>
							<p><strong><a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=R8Q85GT3Q8Q26" >Donate</a></strong></p>
							<hr>
							<br>
							<h3><?php _e( 'Premium Extension Available', 'wp-embed-facebook' ) ?></h3>
							<br>
							<div class="features-list">
							<p><?php _e( 'Embed a Facebook Page with all its details.', 'wp-embed-facebook' ) ?></p>
							<p><?php _e( 'Embed an Event with all its details.', 'wp-embed-facebook' ) ?></p>
							<p><?php _e( 'One Year Premium Support', 'wp-embed-facebook' ) ?></p>
							<p>
								<?php _e( 'Plus new features cooking', 'wp-embed-facebook' ) ?>
								<br>
								<small>
									<?php _e( 'Upcoming events widget, events with maps...', 'wp-embed-facebook' ) ?>
								</small>
							</p>
							</div>
							<h2><?php _e( 'Only $6.99 USD', 'wp-embed-facebook' ) ?><br><small style="font-size: 12px; color: #d0d0d0">Price will change very soon</small></h2>
							<br>
							<a class="button button-red"
							   href="http://www.wpembedfb.com/premium"><?php _e( 'Check it out', 'wp-embed-facebook' ) ?></a>
							<br>
							<br>
							<hr>
							<p><a href="http://www.wpembedfb.com"><small><?php _e( 'More information', 'wp-embed-facebook' ) ?></small></a></p>
							<?php echo apply_filters( 'wpemfb_admin', ob_get_clean() ); ?>
						</div>
					</div>
				</div>
			</div>
		</div>
		<script>

		</script>
		<?php
	}
}