<?php
class WP_Embed_FB_Plugin {
	/**
	 * @var string Plugin directory
	 */
	private static $path = null;
	/**
	 * @var string Plugin url
	 */
	private static $url = null;
	/**
	 * @var string Plugin slug
	 */
	private static $slug = null;
	/**
	 * Save default values to data base
	 */
	static function install(){
		$defaults = self::getdefaults();
		foreach ($defaults as $option => $value) {
			$opt = get_option($option);
			if($opt === false)
				update_option($option, $value);
			if(!isset($type))
				$type = $opt==false?"activated":"reactivated";
		}
		return self::whois($type);
	}
	/**
	 * Delete all plugin options on uninstall
	 */
	static function uninstall(){
		$defaults = self::getdefaults();
		if ( is_multisite() ) {
			$sites = wp_get_sites();
			foreach ($sites as $site) {
				switch_to_blog($site['blog_id']);
				foreach ($defaults as $option => $value ) {
					delete_option($option);
				}
			}
			restore_current_blog();
		} else {
			foreach ($defaults as $option => $value ) {
				delete_option($option);
			}
		}
		return self::whois('uninstalled');
	}
	static function deactivate(){
		return self::whois('deactivated');
	}
	/**
	 * @return array plugin defaults
	 */
	static function getdefaults(){
		return array(
			'wpemfb_max_width' 		=> '450',
			'wpemfb_max_photos' 	=> '24',
			'wpemfb_max_posts' 		=> '2',
			'wpemfb_show_posts' 	=> 'false',
			'wpemfb_enqueue_style' 	=> 'true',
			'wpemfb_app_id' 		=> '0',
			'wpemfb_app_secret'		=> '0',
			'wpemfb_proportions' 	=> 0.36867,
			'wpemfb_height'			=> '221.202',
			'wpemfb_show_like'		=> 'true',
			'wpemfb_fb_root'		=> 'true',
			'wpemfb_theme'			=> 'default',
			'wpemfb_show_follow'	=> 'true',
			'wpemfb_video_ratio'	=> 'false',
			'wpemfb_raw_video'		=> 'true',
			'wpemfb_video_as_post'	=> 'true',
			'wpemfb_raw_photo'		=> 'false',
			'wpemfb_raw_post'		=> 'true',
			'wpemfb_raw_page'       => 'true',
			'wpemfb_enq_lightbox'	=> 'true',
			'wpemfb_enq_wpemfb'		=> 'true',
			'wpemfb_enq_fbjs'		=> 'true',
			'wpemfb_ev_local_tz'    => 'false',
		);
	}
	//("uninstalled","deactivated","activated","reactivated")
	protected static function whois($install){
		$home = home_url();
		$home = esc_url($home);
		@file_get_contents("http://www.wpembedfb.com/api/?whois=$install&site_url=$home");
		return true;
	}
	/**
	 * load translations and facebook sdk
	 */
	static function init(){
		if(version_compare(phpversion(), '5.4.0', '<')) {
			if(session_id() == '')
				session_start();
		} elseif(session_status() == PHP_SESSION_NONE) {
			session_start();
		}
		load_plugin_textdomain( 'wp-embed-facebook', false, self::get_slug() . '/lang' );
	}
	/**
	 * Enqueue wp embed facebook styles
	 */
	static function wp_enqueue_scripts(){
		if(get_option('wpemfb_enqueue_style') == 'true'){
			$theme = get_option('wpemfb_theme');
			wp_enqueue_style('wpemfb-'.$theme, self::get_url().'templates/'.$theme.'/'.$theme.'.css',array(),false);
			wp_enqueue_style('wpemfb-lightbox', self::get_url().'lib/lightbox2/css/lightbox.css',array(),false);
		}
		if(get_option('wpemfb_enq_lightbox') == 'true'){
			wp_enqueue_script(
				'wpemfb-lightbox',
				self::get_url().'lib/lightbox2/js/lightbox.min.js',
				array( 'jquery' )
			);
		}
		if(get_option('wpemfb_enq_wpemfb') == 'true'){
			wp_enqueue_script(
				'wpemfb',
				self::get_url().'lib/js/wpembedfb.js',
				array( 'jquery' )
			);
		}
		if(get_option('wpemfb_enq_fbjs') == 'true'){
			wp_enqueue_script(
				'wpemfb-fbjs',
				self::get_url().'lib/js/fb.js',
				array( 'jquery' )
			);
			$translation_array = array( 'local' => get_locale(), 'fb_id'=>get_option('wpemfb_app_id') );
			wp_localize_script( 'wpemfb-fbjs', 'WEF', $translation_array );
		}
	}
	static function get_path(){
		if(self::$path){
			return self::$path;
		} else {
			self::$path = dirname(plugin_dir_path( __FILE__ )).'/';
			return self::$path;
		}
	}
	static function get_url(){
		if(self::$url){
			return self::$url;
		} else {
			self::$url = dirname(plugin_dir_url( __FILE__ )).'/';
			return self::$url;
		}
	}
	static function get_slug(){
		if(self::$slug){
			return self::$slug;
		} else {
			self::$slug = dirname(dirname(plugin_basename(__FILE__)));
			return self::$slug;
		}
	}
	static function fb_root($content){
		return '<div id="fb-root"></div>'.PHP_EOL.$content;
	}
}